shutdown_cleanup

Function shutdown_cleanup 

pub async fn shutdown_cleanup(db: &SqlitePool, timeout: Option<Duration>)
Run cleanup tasks after the server stops accepting connections.

Currently this closes the SQLite connection pool, waiting up to timeout for in-flight queries to complete. If no timeout is provided the default of 30 seconds is used.